@@ -24,11 +24,19 @@ import netifaces
 import fnmatch
 import re
 
+import netplan.libnetplan as np
+from netplan.configmanager import ConfigurationError
+from netplan.libnetplan import LibNetplanException
+
+
 NM_SERVICE_NAME = 'NetworkManager.service'
 NM_SNAP_SERVICE_NAME = 'snap.network-manager.networkmanager.service'
 
+config_errors = (ConfigurationError, LibNetplanException, RuntimeError)
+
 
 def get_generator_path():
+    # FIXME: meson build uses proper libexecdir (+symlink)
     return os.environ.get('NETPLAN_GENERATE_PATH', '/lib/netplan/generate')
 
 
@@ -77,7 +85,7 @@ def systemctl_network_manager(action, sync=False):
     return systemctl(action, [NM_SERVICE_NAME], sync)  # pragma: nocover (covered in autopkgtest)
 
 
-def systemctl(action, services, sync=False):
+def systemctl(action: str, services: list, sync: bool = False):
     if len(services) >= 1:
         command = ['systemctl', action]
 
@@ -95,12 +103,15 @@ def networkd_interfaces():
     for line in out.splitlines():
         s = line.strip().split(' ')
         if s[0].isnumeric() and s[-1] not in ['unmanaged', 'linger']:
-            interfaces.add(s[1])
+            interfaces.add(s[0])
     return interfaces
 
 
-def networkctl_reconfigure(interfaces):
+def networkctl_reload():
     subprocess.check_call(['networkctl', 'reload'])
+
+
+def networkctl_reconfigure(interfaces):
     if len(interfaces) >= 1:
         subprocess.check_call(['networkctl', 'reconfigure'] + list(interfaces))
 
@@ -112,6 +123,16 @@ def systemctl_is_active(unit_pattern):
     return False
 
 
+def systemctl_is_masked(unit_pattern):
+    '''Return True if output is "masked" or "masked-runtime"'''
+    res = subprocess.run(['systemctl', 'is-enabled', unit_pattern],
+                         stdout=subprocess.PIPE, stderr=subprocess.PIPE,
+                         universal_newlines=True)
+    if res.returncode > 0 and 'masked' in res.stdout:
+        return True
+    return False
+
+
 def systemctl_daemon_reload():
     '''Reload systemd unit files from disk and re-calculate its dependencies'''
     subprocess.check_call(['systemctl', 'daemon-reload'])
@@ -151,43 +172,14 @@ def get_interface_macaddress(interface):
     return link.get('addr', '')
 
 
-def is_interface_matching_name(interface, match_name):
-    # globs are supported
-    return fnmatch.fnmatchcase(interface, match_name)
+def find_matching_iface(interfaces: list, netdef):
+    assert isinstance(netdef, np.NetDefinition)
+    assert netdef.has_match
 
-
-def is_interface_matching_driver_name(interface, match_driver):
-    driver_globs = match_driver
-    if isinstance(driver_globs, str):
-        driver_globs = [match_driver]
-    driver_name = get_interface_driver_name(interface)
-    # globs are supported
-    return any(
-        fnmatch.fnmatchcase(driver_name, pattern)
-        for pattern in driver_globs
-    )
-
-
-def is_interface_matching_macaddress(interface, match_mac):
-    macaddress = get_interface_macaddress(interface)
-    # exact, case insensitive match. globs are not supported
-    return match_mac.lower() == macaddress.lower()
-
-
-def find_matching_iface(interfaces, match):
-    assert isinstance(match, dict)
-
-    # Filter for match.name glob, fallback to '*'
-    name_glob = match.get('name') if match.get('name', False) else '*'
-    matches = fnmatch.filter(interfaces, name_glob)
-
-    # Filter for match.macaddress (exact match)
-    if len(matches) > 1 and match.get('macaddress'):
-        matches = list(filter(lambda iface: is_interface_matching_macaddress(iface, match.get('macaddress')), matches))
-
-    # Filter for match.driver glob
-    if len(matches) > 1 and match.get('driver'):
-        matches = list(filter(lambda iface: is_interface_matching_driver_name(iface, match.get('driver')), matches))
+    matches = list(filter(lambda itf: netdef.match_interface(
+            itf_name=itf,
+            itf_driver=get_interface_driver_name(itf),
+            itf_mac=get_interface_macaddress(itf)), interfaces))
 
     # Return current name of unique matched interface, if available
     if len(matches) != 1:
@@ -205,6 +197,7 @@ class NetplanCommand(argparse.Namespace):
         self.testing = testing
         self._args = None
         self.debug = False
+        self.breakpoint = False
         self.commandclass = None
         self.subcommands = {}
         self.subcommand = None
@@ -215,6 +208,8 @@ class NetplanCommand(argparse.Namespace):
                                               add_help=True)
         self.parser.add_argument('--debug', action='store_true',
                                  help='Enable debug messages')
+        self.parser.add_argument('--breakpoint', action='store_true',
+                                 help=argparse.SUPPRESS)
         if not leaf:
             self.subparsers = self.parser.add_subparsers(title='Available commands',
                                                          metavar='', dest='subcommand')
@@ -241,6 +236,8 @@ class NetplanCommand(argparse.Namespace):
         if self.leaf_command and 'help' in self._args:  # pragma: nocover (covered in autopkgtest)
             self.print_usage()
 
+        if self.breakpoint:  # pragma: nocover (cannot be automatically tested)
+            breakpoint()
         self.func()
 
     def print_usage(self):
