@@ -224,12 +224,12 @@ struct netplan_net_definition {
         gboolean ipv6;
     } linklocal;
 
-    /* master ID for slave devices */
-    char* bridge;
-    char* bond;
+    /* primary ID for member devices */
+    char* bridge; // deprecated, use bridge_link instead
+    char* bond;   // deprecated, use bond_link instead
 
     /* peer ID for OVS patch ports */
-    char* peer;
+    char* peer;   // deprecated, use peer_link instead
 
     /* vlan */
     guint vlan_id;
@@ -268,7 +268,7 @@ struct netplan_net_definition {
         guint min_links;
         char* transmit_hash_policy;
         char* selection_logic;
-        gboolean all_slaves_active;
+        gboolean all_members_active;
         char* arp_interval;
         GArray* arp_ip_targets;
         char* arp_validate;
@@ -278,11 +278,11 @@ struct netplan_net_definition {
         char* fail_over_mac_policy;
         guint gratuitous_arp;
         /* TODO: unsolicited_na */
-        guint packets_per_slave;
+        guint packets_per_member;
         char* primary_reselect_policy;
         guint resend_igmp;
         char* learn_interval;
-        char* primary_slave;
+        char* primary_member;
     } bond_params;
 
     /* netplan-feature: modems */
@@ -327,7 +327,7 @@ struct netplan_net_definition {
 
     /* these properties are only valid for SR-IOV NICs */
     /* netplan-feature: sriov */
-    struct netplan_net_definition* sriov_link;
+    NetplanNetDefinition* sriov_link;
     gboolean sriov_vlan_filter;
     guint sriov_explicit_vf_count;
 
@@ -379,4 +379,8 @@ struct netplan_net_definition {
     /* netplan-feature: vxlan */
     gboolean has_vxlans;
     NetplanVxlan* vxlan;
+
+    NetplanNetDefinition* bridge_link;
+    NetplanNetDefinition* bond_link;
+    NetplanNetDefinition* peer_link;
 };
