@@ -23,7 +23,7 @@
 #include "parse-nm.h"
 #include "parse.h"
 #include "util.h"
-#include "types.h"
+#include "types-internal.h"
 #include "util-internal.h"
 #include "validation.h"
 
@@ -446,6 +446,7 @@ netplan_parser_load_keyfile(NetplanParser* npp, const char* filename, GError** e
     g_autofree gchar* wifi_mode = NULL;
     g_autofree gchar* ssid = NULL;
     g_autofree gchar* netdef_id = NULL;
+    ssize_t netdef_id_size = 0;
     gchar *tmp_str = NULL;
     NetplanNetDefinition* nd = NULL;
     NetplanWifiAccessPoint* ap = NULL;
@@ -460,7 +461,8 @@ netplan_parser_load_keyfile(NetplanParser* npp, const char* filename, GError** e
     if (!ssid)
         ssid = g_key_file_get_string(kf, "802-11-wireless", "ssid", NULL);
 
-    netdef_id = netplan_get_id_from_nm_filename(filename, ssid);
+    netdef_id = g_malloc0(strlen(filename));
+    netdef_id_size = netplan_get_id_from_nm_filepath(filename, ssid, netdef_id, strlen(filename));
     uuid = g_key_file_get_string(kf, "connection", "uuid", NULL);
     if (!uuid) {
         g_warning("netplan: Keyfile: cannot find connection.uuid");
@@ -477,7 +479,7 @@ netplan_parser_load_keyfile(NetplanParser* npp, const char* filename, GError** e
     tmp_str = g_key_file_get_string(kf, "connection", "interface-name", NULL);
     /* Use previously existing netdef IDs, if available, to override connections
      * Else: generate a "NM-<UUID>" ID */
-    if (netdef_id) {
+    if (netdef_id_size > 0) {
         nd_id = g_strdup(netdef_id);
         if (g_strcmp0(netdef_id, tmp_str) == 0)
             _kf_clear_key(kf, "connection", "interface-name");
@@ -614,7 +616,9 @@ netplan_parser_load_keyfile(NetplanParser* npp, const char* filename, GError** e
     if (g_key_file_has_group(kf, "ethernet")) {
         /* wake-on-lan, do not clear passthrough as we do not fully support this setting */
         if (!g_key_file_has_key(kf, "ethernet", "wake-on-lan", NULL)) {
-            nd->wake_on_lan = TRUE; //NM's default is "1"
+            /* apply the default only to actual ethernet devices */
+            if (nd_type == NETPLAN_DEF_TYPE_ETHERNET)
+                nd->wake_on_lan = TRUE; //NM's default is "1"
         } else {
             guint value = g_key_file_get_uint64(kf, "ethernet", "wake-on-lan", NULL);
             //XXX: fix delta between options in NM (0x1, 0x2, 0x4, ...) and netplan (bool)
@@ -686,16 +690,16 @@ netplan_parser_load_keyfile(NetplanParser* npp, const char* filename, GError** e
     handle_generic_str(kf, "bond", "fail_over_mac", &nd->bond_params.fail_over_mac_policy);
     handle_generic_str(kf, "bond", "primary_reselect", &nd->bond_params.primary_reselect_policy);
     handle_generic_str(kf, "bond", "lp_interval", &nd->bond_params.learn_interval);
-    handle_generic_str(kf, "bond", "primary", &nd->bond_params.primary_slave);
+    handle_generic_str(kf, "bond", "primary", &nd->bond_params.primary_member);
     handle_generic_uint(kf, "bond", "min_links", &nd->bond_params.min_links, 0);
     handle_generic_uint(kf, "bond", "resend_igmp", &nd->bond_params.resend_igmp, 0);
-    handle_generic_uint(kf, "bond", "packets_per_slave", &nd->bond_params.packets_per_slave, 0);
+    handle_generic_uint(kf, "bond", "packets_per_slave", &nd->bond_params.packets_per_member, 0); /* wokeignore:rule=slave */
     handle_generic_uint(kf, "bond", "num_grat_arp", &nd->bond_params.gratuitous_arp, 0);
     /* num_unsol_na might overwrite num_grat_arp, but we're fine if they are equal:
      * https://github.com/NetworkManager/NetworkManager/commit/42b0bef33c77a0921590b2697f077e8ea7805166 */
     if (g_key_file_get_uint64(kf, "bond", "num_unsol_na", NULL) == nd->bond_params.gratuitous_arp)
         _kf_clear_key(kf, "bond", "num_unsol_na");
-    handle_generic_bool(kf, "bond", "all_slaves_active", &nd->bond_params.all_slaves_active);
+    handle_generic_bool(kf, "bond", "all_slaves_active", &nd->bond_params.all_members_active); /* wokeignore:rule=slave */
     parse_bond_arp_ip_targets(kf, &nd->bond_params.arp_ip_targets);
 
     /* Special handling for WiFi "access-points:" mapping */
@@ -704,6 +708,7 @@ netplan_parser_load_keyfile(NetplanParser* npp, const char* filename, GError** e
         ap->ssid = g_key_file_get_string(kf, "wifi", "ssid", NULL);
         if (!ap->ssid) {
             g_warning("netplan: Keyfile: cannot find SSID for WiFi connection");
+            g_free(ap);
             return FALSE;
         } else
             _kf_clear_key(kf, "wifi", "ssid");
