@@ -145,7 +145,7 @@ UseMTU=true
                               'switchports.network': '[Match]\nDriver=yayroute\n\n'
                                                      '[Network]\nLinkLocalAddressing=no\nBond=bn0\n'})
 
-    def test_bond_with_parameters(self):
+    def test_bond_with_parameters_all_members_active(self):
         self.generate('''network:
   version: 2
   ethernets:
@@ -162,7 +162,7 @@ UseMTU=true
         min-links: 10
         up-delay: 20
         down-delay: 30
-        all-slaves-active: true
+        all-members-active: true
         transmit-hash-policy: none
         ad-select: none
         arp-interval: 15
@@ -170,7 +170,7 @@ UseMTU=true
         arp-all-targets: all
         fail-over-mac-policy: none
         gratuitious-arp: 10
-        packets-per-slave: 10
+        packets-per-member: 10
         primary-reselect-policy: none
         resend-igmp: 10
         learn-packet-interval: 10
@@ -188,7 +188,7 @@ UseMTU=true
                                             'MinLinks=10\n'
                                             'TransmitHashPolicy=none\n'
                                             'AdSelect=none\n'
-                                            'AllSlavesActive=1\n'
+                                            'AllSlavesActive=1\n'  # wokeignore:rule=slave
                                             'ARPIntervalSec=15ms\n'
                                             'ARPIPTargets=10.10.10.10 20.20.20.20\n'
                                             'ARPValidate=all\n'
@@ -197,7 +197,82 @@ UseMTU=true
                                             'DownDelaySec=30ms\n'
                                             'FailOverMACPolicy=none\n'
                                             'GratuitousARP=10\n'
-                                            'PacketsPerSlave=10\n'
+                                            'PacketsPerSlave=10\n'  # wokeignore:rule=slave
+                                            'PrimaryReselectPolicy=none\n'
+                                            'ResendIGMP=10\n'
+                                            'LearnPacketIntervalSec=10\n',
+                              'bn0.network': '''[Match]
+Name=bn0
+
+[Network]
+DHCP=ipv4
+LinkLocalAddressing=ipv6
+ConfigureWithoutCarrier=yes
+
+[DHCP]
+RouteMetric=100
+UseMTU=true
+''',
+                              'eno1.network': '[Match]\nName=eno1\n\n'
+                                              '[Network]\nLinkLocalAddressing=no\nBond=bn0\n',
+                              'switchports.network': '[Match]\nDriver=yayroute\n\n'
+                                                     '[Network]\nLinkLocalAddressing=no\nBond=bn0\n'})
+
+    def test_bond_with_parameters(self):
+        self.generate('''network:
+  version: 2
+  ethernets:
+    eno1: {}
+    switchports:
+      match:
+        driver: yayroute
+  bonds:
+    bn0:
+      parameters:
+        mode: 802.3ad
+        lacp-rate: 10
+        mii-monitor-interval: 10
+        min-links: 10
+        up-delay: 20
+        down-delay: 30
+        all-slaves-active: true  # wokeignore:rule=slave
+        transmit-hash-policy: none
+        ad-select: none
+        arp-interval: 15
+        arp-validate: all
+        arp-all-targets: all
+        fail-over-mac-policy: none
+        gratuitious-arp: 10
+        packets-per-slave: 10  # wokeignore:rule=slave
+        primary-reselect-policy: none
+        resend-igmp: 10
+        learn-packet-interval: 10
+        arp-ip-targets:
+          - 10.10.10.10
+          - 20.20.20.20
+      interfaces: [eno1, switchports]
+      dhcp4: true''', skip_generated_yaml_validation=True)
+        # Skipping the yaml validation above because the emitter will use
+        # all-members-active and packets-per-member by default.
+
+        self.assert_networkd({'bn0.netdev': '[NetDev]\nName=bn0\nKind=bond\n\n'
+                                            '[Bond]\n'
+                                            'Mode=802.3ad\n'
+                                            'LACPTransmitRate=10\n'
+                                            'MIIMonitorSec=10ms\n'
+                                            'MinLinks=10\n'
+                                            'TransmitHashPolicy=none\n'
+                                            'AdSelect=none\n'
+                                            'AllSlavesActive=1\n'  # wokeignore:rule=slave
+                                            'ARPIntervalSec=15ms\n'
+                                            'ARPIPTargets=10.10.10.10 20.20.20.20\n'
+                                            'ARPValidate=all\n'
+                                            'ARPAllTargets=all\n'
+                                            'UpDelaySec=20ms\n'
+                                            'DownDelaySec=30ms\n'
+                                            'FailOverMACPolicy=none\n'
+                                            'GratuitousARP=10\n'
+                                            'PacketsPerSlave=10\n'  # wokeignore:rule=slave
                                             'PrimaryReselectPolicy=none\n'
                                             'ResendIGMP=10\n'
                                             'LearnPacketIntervalSec=10\n',
@@ -261,7 +336,7 @@ UseMTU=true
                               'switchports.network': '[Match]\nDriver=yayroute\n\n'
                                                      '[Network]\nLinkLocalAddressing=no\nBond=bn0\n'})
 
-    def test_bond_primary_slave(self):
+    def test_bond_primary_member(self):
         self.generate('''network:
   version: 2
   ethernets:
@@ -293,18 +368,19 @@ RouteMetric=100
 UseMTU=true
 ''',
                               'eno1.network': '[Match]\nName=eno1\n\n'
-                                              '[Network]\nLinkLocalAddressing=no\nBond=bn0\nPrimarySlave=true\n',
+                                              '[Network]\nLinkLocalAddressing=no\nBond=bn0\n'
+                                              'PrimarySlave=true\n',  # wokeignore:rule=slave
                               'switchports.network': '[Match]\nDriver=yayroute\n\n'
                                                      '[Network]\nLinkLocalAddressing=no\nBond=bn0\n'})
 
-    def test_bond_primary_slave_duplicate(self):
+    def test_bond_primary_member_duplicate(self):
         self.generate('''network:
   version: 2
   renderer: networkd
   ethernets:
     eno1: {}
     enp65s0: {}
-    dummy2: {}
+    faketh2: {}
   bonds:
     bond0:
       interfaces: [eno1, enp65s0]
@@ -317,7 +393,7 @@ UseMTU=true
       link: vbr
   bridges:
     vbr:
-      interfaces: [dummy2]''', expect_fail=False)
+      interfaces: [faketh2]''', expect_fail=False)
 
         self.assert_networkd({'eno1.network': '[Match]\nName=eno1\n\n[Network]\nLinkLocalAddressing=no\nBond=bond0\n',
                               'enp65s0.network': '''[Match]
@@ -326,11 +402,11 @@ Name=enp65s0
 [Network]
 LinkLocalAddressing=no
 Bond=bond0
-PrimarySlave=true
+PrimarySlave=true # wokeignore:rule=slave
 ''',
-                              'dummy2.network': '[Match]\nName=dummy2\n\n[Network]\nLinkLocalAddressing=no\nBridge=vbr\n',
+                              'faketh2.network': '[Match]\nName=faketh2\n\n[Network]\nLinkLocalAddressing=no\nBridge=vbr\n',
                               'bond0.network': '[Match]\nName=bond0\n\n'
-                                                '[Network]\nLinkLocalAddressing=ipv6\nConfigureWithoutCarrier=yes\n',
+                                               '[Network]\nLinkLocalAddressing=ipv6\nConfigureWithoutCarrier=yes\n',
                               'bond0.netdev': '[NetDev]\nName=bond0\nKind=bond\n\n[Bond]\nMode=balance-tlb\n',
                               'vbr-v10.network': '[Match]\nName=vbr-v10\n\n'
                                                  '[Network]\nLinkLocalAddressing=ipv6\nConfigureWithoutCarrier=yes\n',
@@ -418,8 +494,8 @@ method=ignore
 id=netplan-eno1
 type=ethernet
 interface-name=eno1
-slave-type=bond
-master=bn0
+slave-type=bond # wokeignore:rule=slave
+master=bn0 # wokeignore:rule=master
 
 [ethernet]
 wake-on-lan=0
@@ -434,8 +510,8 @@ method=ignore
 id=netplan-switchport
 type=ethernet
 interface-name=enp2s1
-slave-type=bond
-master=bn0
+slave-type=bond # wokeignore:rule=slave
+master=bn0 # wokeignore:rule=master
 
 [ethernet]
 wake-on-lan=0
@@ -479,8 +555,8 @@ method=ignore
 id=netplan-eno1
 type=ethernet
 interface-name=eno1
-slave-type=bond
-master=bn0
+slave-type=bond # wokeignore:rule=slave
+master=bn0 # wokeignore:rule=master
 
 [ethernet]
 wake-on-lan=0
@@ -495,8 +571,8 @@ method=ignore
 id=netplan-switchport
 type=ethernet
 interface-name=enp2s1
-slave-type=bond
-master=bn0
+slave-type=bond # wokeignore:rule=slave
+master=bn0 # wokeignore:rule=master
 
 [ethernet]
 wake-on-lan=0
@@ -515,6 +591,110 @@ interface-name=bn0
 [ipv4]
 method=auto
 
+[ipv6]
+method=ignore
+'''})
+        self.assert_networkd({})
+        self.assert_nm_udev(NM_MANAGED % 'eno1' + NM_MANAGED % 'enp2s1' + NM_MANAGED % 'bn0')
+
+    def test_bond_with_params_all_members_active(self):
+        self.generate('''network:
+  version: 2
+  renderer: NetworkManager
+  ethernets:
+    eno1: {}
+    switchport:
+      match:
+        name: enp2s1
+  bonds:
+    bn0:
+      interfaces: [eno1, switchport]
+      parameters:
+        mode: 802.3ad
+        lacp-rate: 10
+        mii-monitor-interval: 10
+        min-links: 10
+        up-delay: 10
+        down-delay: 10
+        all-members-active: true
+        transmit-hash-policy: none
+        ad-select: none
+        arp-interval: 10
+        arp-validate: all
+        arp-all-targets: all
+        arp-ip-targets:
+          - 10.10.10.10
+          - 20.20.20.20
+        fail-over-mac-policy: none
+        gratuitious-arp: 10
+        packets-per-member: 10
+        primary-reselect-policy: none
+        resend-igmp: 10
+        learn-packet-interval: 10
+      dhcp4: true''')
+
+        self.assert_nm({'eno1': '''[connection]
+id=netplan-eno1
+type=ethernet
+interface-name=eno1
+slave-type=bond # wokeignore:rule=slave
+master=bn0 # wokeignore:rule=master
+
+[ethernet]
+wake-on-lan=0
+
+[ipv4]
+method=link-local
+
+[ipv6]
+method=ignore
+''',
+                        'switchport': '''[connection]
+id=netplan-switchport
+type=ethernet
+interface-name=enp2s1
+slave-type=bond # wokeignore:rule=slave
+master=bn0 # wokeignore:rule=master
+
+[ethernet]
+wake-on-lan=0
+
+[ipv4]
+method=link-local
+
+[ipv6]
+method=ignore
+''',
+                        'bn0': '''[connection]
+id=netplan-bn0
+type=bond
+interface-name=bn0
+
+[bond]
+mode=802.3ad
+lacp_rate=10
+miimon=10
+min_links=10
+xmit_hash_policy=none
+ad_select=none
+all_slaves_active=1 # wokeignore:rule=slave
+arp_interval=10
+arp_ip_target=10.10.10.10,20.20.20.20
+arp_validate=all
+arp_all_targets=all
+updelay=10
+downdelay=10
+fail_over_mac=none
+num_grat_arp=10
+num_unsol_na=10
+packets_per_slave=10 # wokeignore:rule=slave
+primary_reselect=none
+resend_igmp=10
+lp_interval=10
+
+[ipv4]
+method=auto
+
 [ipv6]
 method=ignore
 '''})
@@ -540,7 +720,7 @@ method=ignore
         min-links: 10
         up-delay: 10
         down-delay: 10
-        all-slaves-active: true
+        all-slaves-active: true # wokeignore:rule=slave
         transmit-hash-policy: none
         ad-select: none
         arp-interval: 10
@@ -551,18 +731,20 @@ method=ignore
           - 20.20.20.20
         fail-over-mac-policy: none
         gratuitious-arp: 10
-        packets-per-slave: 10
+        packets-per-slave: 10 # wokeignore:rule=slave
         primary-reselect-policy: none
         resend-igmp: 10
         learn-packet-interval: 10
-      dhcp4: true''')
+      dhcp4: true''', skip_generated_yaml_validation=True)
+        # Skipping the yaml validation above because the emitter will use
+        # all-members-active and packets-per-member by default.
 
         self.assert_nm({'eno1': '''[connection]
 id=netplan-eno1
 type=ethernet
 interface-name=eno1
-slave-type=bond
-master=bn0
+slave-type=bond # wokeignore:rule=slave
+master=bn0 # wokeignore:rule=master
 
 [ethernet]
 wake-on-lan=0
@@ -577,8 +759,8 @@ method=ignore
 id=netplan-switchport
 type=ethernet
 interface-name=enp2s1
-slave-type=bond
-master=bn0
+slave-type=bond # wokeignore:rule=slave
+master=bn0 # wokeignore:rule=master
 
 [ethernet]
 wake-on-lan=0
@@ -601,7 +783,7 @@ miimon=10
 min_links=10
 xmit_hash_policy=none
 ad_select=none
-all_slaves_active=1
+all_slaves_active=1 # wokeignore:rule=slave
 arp_interval=10
 arp_ip_target=10.10.10.10,20.20.20.20
 arp_validate=all
@@ -611,7 +793,7 @@ downdelay=10
 fail_over_mac=none
 num_grat_arp=10
 num_unsol_na=10
-packets_per_slave=10
+packets_per_slave=10 # wokeignore:rule=slave
 primary_reselect=none
 resend_igmp=10
 lp_interval=10
@@ -625,7 +807,7 @@ method=ignore
         self.assert_networkd({})
         self.assert_nm_udev(NM_MANAGED % 'eno1' + NM_MANAGED % 'enp2s1' + NM_MANAGED % 'bn0')
 
-    def test_bond_primary_slave(self):
+    def test_bond_primary_member(self):
         self.generate('''network:
   version: 2
   renderer: NetworkManager
@@ -646,8 +828,8 @@ method=ignore
 id=netplan-eno1
 type=ethernet
 interface-name=eno1
-slave-type=bond
-master=bn0
+slave-type=bond # wokeignore:rule=slave
+master=bn0 # wokeignore:rule=master
 
 [ethernet]
 wake-on-lan=0
@@ -662,8 +844,8 @@ method=ignore
 id=netplan-switchport
 type=ethernet
 interface-name=enp2s1
-slave-type=bond
-master=bn0
+slave-type=bond # wokeignore:rule=slave
+master=bn0 # wokeignore:rule=master
 
 [ethernet]
 wake-on-lan=0
@@ -727,7 +909,7 @@ class TestConfigErrors(TestBase):
           - 2001:dead:beef::1
       dhcp4: true''', expect_fail=True)
 
-    def test_bond_invalid_primary_slave(self):
+    def test_bond_invalid_primary_member(self):
         self.generate('''network:
   version: 2
   ethernets:
@@ -741,7 +923,7 @@ class TestConfigErrors(TestBase):
         primary: wigglewiggle
       dhcp4: true''', expect_fail=True)
 
-    def test_bond_duplicate_primary_slave(self):
+    def test_bond_duplicate_primary_member(self):
         self.generate('''network:
   version: 2
   ethernets:
