@@ -49,7 +49,7 @@ class _CommonTests():
                                   self.dev_e2_client,
                                   self.state_dhcp4('mybr')])
         self.assert_iface_up(self.dev_e_client, ['inet 192.168.5.[0-9]+/24'])
-        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])
+        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])  # wokeignore:rule=master
         self.assert_iface_up('mybr', ['inet 192.168.6.[0-9]+/24'])
         lines = subprocess.check_output(['bridge', 'link', 'show', 'mybr'],
                                         universal_newlines=True).splitlines()
@@ -80,7 +80,7 @@ class _CommonTests():
         stp: false
       dhcp4: yes''' % {'r': self.backend, 'e2c': self.dev_e2_client})
         self.generate_and_settle([self.dev_e2_client, self.state_dhcp4('mybr')])
-        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])
+        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])  # wokeignore:rule=master
         self.assert_iface_up('mybr', ['inet 192.168.6.[0-9]+/24'])
         lines = subprocess.check_output(['bridge', 'link', 'show', 'mybr'],
                                         universal_newlines=True).splitlines()
@@ -106,7 +106,7 @@ class _CommonTests():
         stp: false
       dhcp4: yes''' % {'r': self.backend, 'e2c': self.dev_e2_client})
         self.generate_and_settle([self.dev_e2_client, self.state_dhcp4('mybr')])
-        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])
+        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])  # wokeignore:rule=master
         self.assert_iface_up('mybr', ['inet 192.168.6.[0-9]+/24'])
         lines = subprocess.check_output(['bridge', 'link', 'show', 'mybr'],
                                         universal_newlines=True).splitlines()
@@ -132,7 +132,7 @@ class _CommonTests():
         stp: false
       dhcp4: yes''' % {'r': self.backend, 'e2c': self.dev_e2_client})
         self.generate_and_settle([self.dev_e2_client, self.state_dhcp4('mybr')])
-        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])
+        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])  # wokeignore:rule=master
         self.assert_iface_up('mybr', ['inet 192.168.6.[0-9]+/24'])
         lines = subprocess.check_output(['bridge', 'link', 'show', 'mybr'],
                                         universal_newlines=True).splitlines()
@@ -158,7 +158,7 @@ class _CommonTests():
         stp: false
       dhcp4: yes''' % {'r': self.backend, 'e2c': self.dev_e2_client})
         self.generate_and_settle([self.dev_e2_client, self.state_dhcp4('mybr')])
-        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])
+        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])  # wokeignore:rule=master
         self.assert_iface_up('mybr', ['inet 192.168.6.[0-9]+/24'])
         lines = subprocess.check_output(['bridge', 'link', 'show', 'mybr'],
                                         universal_newlines=True).splitlines()
@@ -184,7 +184,7 @@ class _CommonTests():
         stp: false
       dhcp4: yes''' % {'r': self.backend, 'e2c': self.dev_e2_client})
         self.generate_and_settle([self.dev_e2_client, self.state_dhcp4('mybr')])
-        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])
+        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])  # wokeignore:rule=master
         self.assert_iface_up('mybr', ['inet 192.168.6.[0-9]+/24'])
         lines = subprocess.check_output(['bridge', 'link', 'show', 'mybr'],
                                         universal_newlines=True).splitlines()
@@ -211,7 +211,7 @@ class _CommonTests():
         stp: false
       dhcp4: yes''' % {'r': self.backend, 'e2c': self.dev_e2_client})
         self.generate_and_settle([self.dev_e2_client, self.state_dhcp4('mybr')])
-        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])
+        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])  # wokeignore:rule=master
         self.assert_iface_up('mybr', ['inet 192.168.6.[0-9]+/24'])
         lines = subprocess.check_output(['bridge', 'link', 'show', 'mybr'],
                                         universal_newlines=True).splitlines()
@@ -238,7 +238,7 @@ class _CommonTests():
         stp: false
       dhcp4: yes''' % {'r': self.backend, 'e2c': self.dev_e2_client})
         self.generate_and_settle([self.dev_e2_client, self.state_dhcp4('mybr')])
-        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])
+        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])  # wokeignore:rule=master
         self.assert_iface_up('mybr', ['inet 192.168.6.[0-9]+/24'])
         lines = subprocess.check_output(['bridge', 'link', 'show', 'mybr'],
                                         universal_newlines=True).splitlines()
@@ -271,8 +271,9 @@ class TestNetworkd(IntegrationTestsBase, _CommonTests):
       dhcp4: yes''' % {'r': self.backend,
                        'ec': self.dev_e_client,
                        'ec_mac': self.dev_e_client_mac})
+        self.match_veth_by_non_permanent_mac_quirk('ethbr', self.dev_e_client_mac)
         self.generate_and_settle([self.dev_e_client, self.state_dhcp4('br0')])
-        self.assert_iface_up(self.dev_e_client, ['master br0'], ['inet '])
+        self.assert_iface_up(self.dev_e_client, ['master br0'], ['inet '])  # wokeignore:rule=master
         self.assert_iface_up('br0', ['inet 192.168.5.[0-9]+/24', 'ether 00:01:02:03:04:05'])
 
     def test_bridge_anonymous(self):
@@ -288,7 +289,7 @@ class TestNetworkd(IntegrationTestsBase, _CommonTests):
     mybr:
       interfaces: [ethbr]''' % {'r': self.backend, 'e2c': self.dev_e2_client})
         self.generate_and_settle([self.dev_e2_client, self.state_up('mybr')])
-        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])
+        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])  # wokeignore:rule=master
         self.assert_iface_up('mybr', [], ['inet 192.168.6.[0-9]+/24'])
         lines = subprocess.check_output(['bridge', 'link', 'show', 'mybr'],
                                         universal_newlines=True).splitlines()
@@ -335,7 +336,7 @@ class TestNetworkManager(IntegrationTestsBase, _CommonTests):
         stp: false
       dhcp4: yes''' % {'r': self.backend, 'e2c': self.dev_e2_client})
         self.generate_and_settle([self.dev_e2_client, self.state_dhcp4('mybr')])
-        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])
+        self.assert_iface_up(self.dev_e2_client, ['master mybr'], ['inet '])  # wokeignore:rule=master
         self.assert_iface_up('mybr', ['inet 192.168.6.[0-9]+/24'])
         lines = subprocess.check_output(['bridge', 'link', 'show', 'mybr'],
                                         universal_newlines=True).splitlines()
