@@ -190,7 +190,7 @@ class _CommonTests():
         self.assertIn(b'    Bridge br-data', out)
         self.assert_iface('br-%s' % self.dev_e_client, ['mtu 9000'])
         self.assert_iface('br-data', ['inet 192.168.20.1/16'])
-        self.assert_iface(self.dev_e_client, ['mtu 9000', 'master ovs-system'])
+        self.assert_iface(self.dev_e_client, ['mtu 9000', 'master ovs-system'])  # wokeignore:rule=master
         self.assertIn(b'100', subprocess.check_output(['ovs-vsctl', '-t', '5', 'br-to-vlan',
                       'br-%s.100' % self.dev_e_client]))
         self.assertIn(b'br-%b' % self.dev_e_client.encode(), subprocess.check_output(
@@ -323,8 +323,8 @@ class _CommonTests():
         self.assertIn(b'---- mybond ----', out)
         self.assertIn(b'bond_mode: balance-slb', out)
         self.assertIn(b'lacp_status: off', out)
-        self.assertRegex(out, br'(slave|member) %b: enabled' % self.dev_e_client.encode())
-        self.assertRegex(out, br'(slave|member) %b: enabled' % self.dev_e2_client.encode())
+        self.assertRegex(out, br'(slave|member) %b: enabled' % self.dev_e_client.encode())  # wokeignore:rule=slave
+        self.assertRegex(out, br'(slave|member) %b: enabled' % self.dev_e2_client.encode())  # wokeignore:rule=slave
         self.assert_iface('ovsbr', ['inet 192.170.1.1/24'])
 
     def test_bridge_patch_ports(self):
@@ -387,9 +387,9 @@ class _CommonTests():
         self.assertIn('''        Port ovs-br
             Interface ovs-br
                 type: internal''', out)
-        self.assert_iface('non-ovs-bond', ['master ovs-system'])
-        self.assert_iface(self.dev_e_client, ['master non-ovs-bond'])
-        self.assert_iface(self.dev_e2_client, ['master non-ovs-bond'])
+        self.assert_iface('non-ovs-bond', ['master ovs-system'])  # wokeignore:rule=master
+        self.assert_iface(self.dev_e_client, ['master non-ovs-bond'])  # wokeignore:rule=master
+        self.assert_iface(self.dev_e2_client, ['master non-ovs-bond'])  # wokeignore:rule=master
 
     def test_vlan_maas(self):
         self.setup_eth(None, False)
@@ -456,6 +456,24 @@ class _CommonTests():
         self.assertIn('ovs0: The \'ovs-vsctl\' tool is required to setup OpenVSwitch interfaces.', err)
         self.assertNotEqual(p.returncode, 0)
 
+    # Netplan shouldn't crash if openvswitch is installed but not running: LP#1995598
+    def test_ovsdb_server_is_not_running(self):
+        self.setup_eth(None, False)
+        self.addCleanup(subprocess.call, ['systemctl', 'start', 'ovsdb-server.service'])
+        self.addCleanup(subprocess.call, ['systemctl', 'start', 'ovs-vswitchd.service'])
+        subprocess.check_call(['systemctl', 'stop', 'ovsdb-server.service'])
+        with open(self.config, 'w') as f:
+            f.write('''network:
+    version: 2
+    bridges:
+      br0:
+        dhcp4: false''')
+        p = subprocess.Popen(['netplan', 'apply'], stdout=subprocess.PIPE,
+                             stderr=subprocess.PIPE, universal_newlines=True)
+        (_, err) = p.communicate()
+        self.assertIn('Cannot call openvswitch: ovsdb-server.service is not running.', err)
+        self.assertEqual(p.returncode, 0)
+
     def test_settings_tag_cleanup(self):
         self.setup_eth(None, False)
         self.addCleanup(subprocess.call, ['ovs-vsctl', '-t', '5', '--if-exists', 'del-br', 'ovs0'])
